Stan Math Library: stan/math/fwd/mat/fun/multiply.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
multiply.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/typedefs.hpp>`
`#include <stan/math/prim/mat/err/check_multiplicable.hpp>`
`#include <stan/math/fwd/core.hpp>`
`#include <stan/math/fwd/mat/fun/typedefs.hpp>`
`#include <stan/math/fwd/mat/fun/to_fvar.hpp>`
`#include <stan/math/fwd/mat/fun/dot_product.hpp>`
`#include <boost/math/tools/promotion.hpp>`
`#include <stdexcept>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T , int R1, int C1>
Eigen::Matrix< fvar< T >, R1, C1 > | stan::math::multiply (const Eigen::Matrix< fvar< T >, R1, C1 > &m, const fvar< T > &c)
template<typename T , int R2, int C2>
Eigen::Matrix< fvar< T >, R2, C2 > | stan::math::multiply (const Eigen::Matrix< fvar< T >, R2, C2 > &m, const double c)
template<typename T , int R1, int C1>
Eigen::Matrix< fvar< T >, R1, C1 > | stan::math::multiply (const Eigen::Matrix< double, R1, C1 > &m, const fvar< T > &c)
template<typename T , int R1, int C1>
Eigen::Matrix< fvar< T >, R1, C1 > | stan::math::multiply (const fvar< T > &c, const Eigen::Matrix< fvar< T >, R1, C1 > &m)
template<typename T , int R1, int C1>
Eigen::Matrix< fvar< T >, R1, C1 > | stan::math::multiply (const double c, const Eigen::Matrix< fvar< T >, R1, C1 > &m)
template<typename T , int R1, int C1>
Eigen::Matrix< fvar< T >, R1, C1 > | stan::math::multiply (const fvar< T > &c, const Eigen::Matrix< double, R1, C1 > &m)
template<typename T , int R1, int C1, int R2, int C2>
Eigen::Matrix< fvar< T >, R1, C2 > | stan::math::multiply (const Eigen::Matrix< fvar< T >, R1, C1 > &m1, const Eigen::Matrix< fvar< T >, R2, C2 > &m2)
template<typename T , int R1, int C1, int R2, int C2>
Eigen::Matrix< fvar< T >, R1, C2 > | stan::math::multiply (const Eigen::Matrix< fvar< T >, R1, C1 > &m1, const Eigen::Matrix< double, R2, C2 > &m2)
template<typename T , int R1, int C1, int R2, int C2>
Eigen::Matrix< fvar< T >, R1, C2 > | stan::math::multiply (const Eigen::Matrix< double, R1, C1 > &m1, const Eigen::Matrix< fvar< T >, R2, C2 > &m2)
template<typename T , int C1, int R2>
fvar< T > | stan::math::multiply (const Eigen::Matrix< fvar< T >, 1, C1 > &rv, const Eigen::Matrix< fvar< T >, R2, 1 > &v)
template<typename T , int C1, int R2>
fvar< T > | stan::math::multiply (const Eigen::Matrix< fvar< T >, 1, C1 > &rv, const Eigen::Matrix< double, R2, 1 > &v)
template<typename T , int C1, int R2>
fvar< T > | stan::math::multiply (const Eigen::Matrix< double, 1, C1 > &rv, const Eigen::Matrix< fvar< T >, R2, 1 > &v)

[ Stan Home Page ] © 2011–2016, Stan Development Team.